# Changelog

## 0.0.0 (2025-01-16)


### ✨ Features

* add logging and restic plugins, extend run capabilities ([f28d30f](https://github.com/liblaf/cherries/commit/f28d30f990a9cbc876c16e98f8fdf5a2e7f54746))


### 🎫 Chores

* **release:** trigger release-please ([c9a55bf](https://github.com/liblaf/cherries/commit/c9a55bf870bce514a76288827d817d0f3777f65a))


### ♻ Code Refactoring

* simplify Run class by removing abstract base class ([d267065](https://github.com/liblaf/cherries/commit/d26706537fc81d4abd4be87d29511259774053ad))


### 👷 Build System

* initialize project structure and configuration ([91d27cf](https://github.com/liblaf/cherries/commit/91d27cf861b724b1cbaf923eceac7e0177edcadb))
* restructure project and enhance git integration ([bbc24c0](https://github.com/liblaf/cherries/commit/bbc24c019640371f110aaae98d3bf178c8f353f0))
